---
title: Prompt Optimization API Reference
---

# Prompt Optimization API Reference

::: langmem
    handler: python
    options:
      members:
        - create_prompt_optimizer
        - create_multi_prompt_optimizer

::: langmem.prompts.types
    handler: python
    options:
      members:
        - Prompt
        - OptimizerInput
        - MultiPromptOptimizerInput
        - AnnotatedTrajectory
